/* Looks up the username (format: iax2_username) category in codec_passthrough.conf. 
   Returns preferred codec, or originalFormat if extension not found.
*/

#ifndef _CODEC_PASSTHROUGH_H
#define _CODEC_PASSTHROUGH_H

int codec_passthrough_iax2(char *username, char* extension, int originalFormat);
void codec_passthrough_reload(void);

#include <asterisk/logger.h>
#include <asterisk/config.h>
#include <asterisk/lock.h>

AST_MUTEX_DEFINE_STATIC(lock); 

static struct 
{
 unsigned int initialized:1;
 unsigned int enabled:1;
} settings = {0, 0};
	
struct ast_config *config = NULL;
	
void config_init(void)
{
	if (settings.initialized) return;

	ast_mutex_lock(&lock);
	if (!settings.initialized)
	{
		if (config) ast_config_destroy(config);
		config = ast_config_load("codec_passthrough.conf");
		settings.enabled = !!config;
		settings.initialized = 1;	
	}
	ast_mutex_unlock(&lock);
}
	
int codec_passthrough_iax2(char *username, char* extension, int originalFormat)
{
	int format = originalFormat;
	char category_name[84] = "iax_";
	
	config_init();
	if (!settings.enabled) return format;

	strncat(category_name, username, 80); // category is iax_theuser

	ast_mutex_lock(&lock);

	char *codec = ast_variable_retrieve(config, category_name, extension);
	if (codec)
	{
		format = ast_getformatbyname(codec);
		if (!format) format = originalFormat;
	}

	ast_mutex_unlock(&lock);
	return format;
}
	
void codec_passthrough_reload()
{
	settings.initialized = 0;
	config_init();
}

#endif
